==> metallb-302.0.1%2Bup0.14.9.tgz: metallb/charts/frr-k8s/README.md <==
# frr-k8s

![Version: 0.0.14](https://img.shields.io/badge/Version-0.0.14-informational?style=flat-square) ![Type: application](https://img.shields.io/badge/Type-application-informational?style=flat-square) ![AppVersion: v0.0.14](https://img.shields.io/badge/AppVersion-v0.0.14-informational?style=flat-square)

A cloud native wrapper of FRR

**Homepage:** <https://metallb.universe.tf>

## Source Code

* <https://github.com/metallb/frr-k8s>

## Requirements

Kubernetes: `>= 1.19.0-0`

| Repository | Name | Version |
|------------|------|---------|
|  | crds | 0.0.14 |

## Values

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| crds.enabled | bool | `true` |  |
| crds.validationFailurePolicy | string | `"Fail"` |  |
| frrk8s.affinity | object | `{}` |  |
| frrk8s.alwaysBlock | string | `""` |  |
| frrk8s.disableCertRotation | bool | `false` |  |
| frrk8s.frr.image.pullPolicy | string | `nil` |  |
| frrk8s.frr.image.repository | string | `"quay.io/frrouting/frr"` |  |
| frrk8s.frr.image.tag | string | `"9.1.0"` |  |
| frrk8s.frr.metricsBindAddress | string | `"127.0.0.1"` |  |
| frrk8s.frr.metricsPort | int | `7573` |  |
| frrk8s.frr.resources | object | `{}` |  |
| frrk8s.frr.secureMetricsPort | int | `9141` |  |
| frrk8s.frrMetrics.resources | object | `{}` |  |
| frrk8s.healthPort | int | `8081` |  |
| frrk8s.image.pullPolicy | string | `nil` |  |
| frrk8s.image.repository | string | `"quay.io/metallb/frr-k8s"` |  |
| frrk8s.image.tag | string | `nil` |  |
| frrk8s.labels.app | string | `"frr-k8s"` |  |
| frrk8s.livenessProbe.enabled | bool | `true` |  |
| frrk8s.livenessProbe.failureThreshold | int | `3` |  |
| frrk8s.livenessProbe.initialDelaySeconds | int | `10` |  |
| frrk8s.livenessProbe.periodSeconds | int | `10` |  |
| frrk8s.livenessProbe.successThreshold | int | `1` |  |
| frrk8s.livenessProbe.timeoutSeconds | int | `1` |  |
| frrk8s.logLevel | string | `"info"` | Controller log level. Must be one of: `all`, `debug`, `info`, `warn`, `error` or `none` |
| frrk8s.nodeSelector | object | `{}` |  |
| frrk8s.podAnnotations | object | `{}` |  |
| frrk8s.priorityClassName | string | `""` |  |
| frrk8s.readinessProbe.enabled | bool | `true` |  |
| frrk8s.readinessProbe.failureThreshold | int | `3` |  |
| frrk8s.readinessProbe.initialDelaySeconds | int | `10` |  |
| frrk8s.readinessProbe.periodSeconds | int | `10` |  |
| frrk8s.readinessProbe.successThreshold | int | `1` |  |
| frrk8s.readinessProbe.timeoutSeconds | int | `1` |  |
| frrk8s.reloader.resources | object | `{}` |  |
| frrk8s.resources | object | `{}` |  |
| frrk8s.restartOnRotatorSecretRefresh | bool | `false` |  |
| frrk8s.runtimeClassName | string | `""` |  |
| frrk8s.serviceAccount.annotations | object | `{}` |  |
| frrk8s.serviceAccount.create | bool | `true` |  |
| frrk8s.serviceAccount.name | string | `""` |  |
| frrk8s.startupProbe.enabled | bool | `true` |  |
| frrk8s.startupProbe.failureThreshold | int | `30` |  |
| frrk8s.startupProbe.periodSeconds | int | `5` |  |
| frrk8s.tolerateMaster | bool | `true` |  |
| frrk8s.tolerations | list | `[]` |  |
| frrk8s.updateStrategy.type | string | `"RollingUpdate"` |  |
| fullnameOverride | string | `""` |  |
| nameOverride | string | `""` |  |
| prometheus.metricsBindAddress | string | `"127.0.0.1"` |  |
| prometheus.metricsPort | int | `7572` |  |
| prometheus.metricsTLSSecret | string | `""` |  |
| prometheus.namespace | string | `""` |  |
| prometheus.rbacPrometheus | bool | `false` |  |
| prometheus.rbacProxy.pullPolicy | string | `nil` |  |
| prometheus.rbacProxy.repository | string | `"gcr.io/kubebuilder/kube-rbac-proxy"` |  |
| prometheus.rbacProxy.tag | string | `"v0.12.0"` |  |
| prometheus.scrapeAnnotations | bool | `false` |  |
| prometheus.secureMetricsPort | int | `9140` |  |
| prometheus.serviceAccount | string | `""` |  |
| prometheus.serviceMonitor.additionalLabels | object | `{}` |  |
| prometheus.serviceMonitor.annotations | object | `{}` |  |
| prometheus.serviceMonitor.enabled | bool | `false` |  |
| prometheus.serviceMonitor.interval | string | `nil` |  |
| prometheus.serviceMonitor.jobLabel | string | `"app.kubernetes.io/name"` |  |
| prometheus.serviceMonitor.metricRelabelings | list | `[]` |  |
| prometheus.serviceMonitor.relabelings | list | `[]` |  |
| prometheus.serviceMonitor.tlsConfig.insecureSkipVerify | bool | `true` |  |
| rbac.create | bool | `true` |  |

----------------------------------------------
Autogenerated from chart metadata using [helm-docs v1.10.0](https://github.com/norwoodj/helm-docs/releases/v1.10.0)

==> metallb-999.0.0%2Bup0.14.9.tgz: metallb/charts/frr-k8s/README.md <==
# frr-k8s

![Version: 0.0.16](https://img.shields.io/badge/Version-0.0.16-informational?style=flat-square) ![Type: application](https://img.shields.io/badge/Type-application-informational?style=flat-square) ![AppVersion: v0.0.16](https://img.shields.io/badge/AppVersion-v0.0.16-informational?style=flat-square)

A cloud native wrapper of FRR

**Homepage:** <https://metallb.universe.tf>

## Source Code

* <https://github.com/metallb/frr-k8s>

## Requirements

Kubernetes: `>= 1.19.0-0`

| Repository | Name | Version |
|------------|------|---------|
|  | crds | 0.0.16 |

## Values

| Key | Type | Default | Description |
|-----|------|---------|-------------|
| crds.enabled | bool | `true` |  |
| crds.validationFailurePolicy | string | `"Fail"` |  |
| frrk8s.affinity | object | `{}` |  |
| frrk8s.alwaysBlock | string | `""` |  |
| frrk8s.disableCertRotation | bool | `false` |  |
| frrk8s.frr.acceptIncomingBGPConnections | bool | `false` |  |
| frrk8s.frr.image.pullPolicy | string | `nil` |  |
| frrk8s.frr.image.repository | string | `"registry.opensuse.org/isv/suse/edge/metallb/images/frr"` |  |
| frrk8s.frr.image.tag | string | `"8.5.6"` |  |
| frrk8s.frr.metricsBindAddress | string | `"127.0.0.1"` |  |
| frrk8s.frr.metricsPort | int | `7573` |  |
| frrk8s.frr.resources | object | `{}` |  |
| frrk8s.frr.secureMetricsPort | int | `9141` |  |
| frrk8s.frrMetrics.resources | object | `{}` |  |
| frrk8s.image.pullPolicy | string | `nil` |  |
| frrk8s.image.repository | string | `"registry.opensuse.org/isv/suse/edge/metallb/images/frr-k8s"` |  |
| frrk8s.image.tag | string | `nil` |  |
| frrk8s.labels.app | string | `"frr-k8s"` |  |
| frrk8s.livenessProbe.enabled | bool | `true` |  |
| frrk8s.livenessProbe.failureThreshold | int | `3` |  |
| frrk8s.livenessProbe.initialDelaySeconds | int | `10` |  |
| frrk8s.livenessProbe.periodSeconds | int | `10` |  |
| frrk8s.livenessProbe.successThreshold | int | `1` |  |
| frrk8s.livenessProbe.timeoutSeconds | int | `1` |  |
| frrk8s.logLevel | string | `"info"` | Controller log level. Must be one of: `all`, `debug`, `info`, `warn`, `error` or `none` |
| frrk8s.nodeSelector | object | `{}` |  |
| frrk8s.podAnnotations | object | `{}` |  |
| frrk8s.priorityClassName | string | `""` |  |
| frrk8s.readinessProbe.enabled | bool | `true` |  |
| frrk8s.readinessProbe.failureThreshold | int | `3` |  |
| frrk8s.readinessProbe.initialDelaySeconds | int | `10` |  |
| frrk8s.readinessProbe.periodSeconds | int | `10` |  |
| frrk8s.readinessProbe.successThreshold | int | `1` |  |
| frrk8s.readinessProbe.timeoutSeconds | int | `1` |  |
| frrk8s.reloader.resources | object | `{}` |  |
| frrk8s.resources | object | `{}` |  |
| frrk8s.restartOnRotatorSecretRefresh | bool | `false` |  |
| frrk8s.runtimeClassName | string | `""` |  |
| frrk8s.serviceAccount.annotations | object | `{}` |  |
| frrk8s.serviceAccount.create | bool | `true` |  |
| frrk8s.serviceAccount.name | string | `""` |  |
| frrk8s.startupProbe.enabled | bool | `true` |  |
| frrk8s.startupProbe.failureThreshold | int | `30` |  |
| frrk8s.startupProbe.periodSeconds | int | `5` |  |
| frrk8s.tolerateMaster | bool | `true` |  |
| frrk8s.tolerations | list | `[]` |  |
| frrk8s.updateStrategy.type | string | `"RollingUpdate"` |  |
| fullnameOverride | string | `""` |  |
| nameOverride | string | `""` |  |
| prometheus.metricsBindAddress | string | `"127.0.0.1"` |  |
| prometheus.metricsPort | int | `7572` |  |
| prometheus.metricsTLSSecret | string | `""` |  |
| prometheus.namespace | string | `""` |  |
| prometheus.rbacPrometheus | bool | `false` |  |
| prometheus.rbacProxy.pullPolicy | string | `nil` |  |
| prometheus.rbacProxy.repository | string | `"registry.opensuse.org/isv/suse/edge/metallb/images/kube-rbac-proxy"` |  |
| prometheus.rbacProxy.tag | string | `"v0.18.0"` |  |
| prometheus.scrapeAnnotations | bool | `false` |  |
| prometheus.secureMetricsPort | int | `9140` |  |
| prometheus.serviceAccount | string | `""` |  |
| prometheus.serviceMonitor.additionalLabels | object | `{}` |  |
| prometheus.serviceMonitor.annotations | object | `{}` |  |
| prometheus.serviceMonitor.enabled | bool | `false` |  |
| prometheus.serviceMonitor.interval | string | `nil` |  |
| prometheus.serviceMonitor.jobLabel | string | `"app.kubernetes.io/name"` |  |
| prometheus.serviceMonitor.metricRelabelings | list | `[]` |  |
| prometheus.serviceMonitor.relabelings | list | `[]` |  |
| prometheus.serviceMonitor.tlsConfig.insecureSkipVerify | bool | `true` |  |
| rbac.create | bool | `true` |  |

----------------------------------------------
Autogenerated from chart metadata using [helm-docs v1.10.0](https://github.com/norwoodj/helm-docs/releases/v1.10.0)
